summaryrefslogtreecommitdiff
path: root/.emacs.d
diff options
context:
space:
mode:
authorSean Whitton <spwhitton@spwhitton.name>2018-04-07 13:05:13 -0700
committerSean Whitton <spwhitton@spwhitton.name>2018-04-07 13:06:15 -0700
commit91fadfaedf04241ff71b512b1bb9b3ebad45b607 (patch)
treed6ef74f28b8bb9e69e5f5d6c008f127dc19dd30a /.emacs.d
parent3fe038ceef923df58adaf4e06df7962c078ad03c (diff)
downloaddotfiles-91fadfaedf04241ff71b512b1bb9b3ebad45b607.tar.gz
.emacs.d/{lisp => initlibs}
dirs called 'lisp' has a special meaning in Emacs
Diffstat (limited to '.emacs.d')
-rw-r--r--.emacs.d/init.el8
-rw-r--r--.emacs.d/initlibs/bind-key.el (renamed from .emacs.d/lisp/bind-key.el)0
-rw-r--r--.emacs.d/initlibs/diminish.el (renamed from .emacs.d/lisp/diminish.el)0
-rw-r--r--.emacs.d/initlibs/key-chord.el (renamed from .emacs.d/lisp/key-chord.el)0
-rw-r--r--.emacs.d/initlibs/let-alist.el (renamed from .emacs.d/lisp/let-alist.el)0
-rw-r--r--.emacs.d/initlibs/smex.el (renamed from .emacs.d/lisp/smex.el)0
-rw-r--r--.emacs.d/initlibs/use-package.el (renamed from .emacs.d/lisp/use-package.el)0
7 files changed, 3 insertions, 5 deletions
diff --git a/.emacs.d/lisp/bind-key.el b/.emacs.d/initlibs/bind-key.el
index 995e4816..995e4816 100644
--- a/.emacs.d/lisp/bind-key.el
+++ b/.emacs.d/initlibs/bind-key.el
diff --git a/.emacs.d/lisp/diminish.el b/.emacs.d/initlibs/diminish.el
index ae92ea8e..ae92ea8e 100644
--- a/.emacs.d/lisp/diminish.el
+++ b/.emacs.d/initlibs/diminish.el
diff --git a/.emacs.d/lisp/key-chord.el b/.emacs.d/initlibs/key-chord.el
index b5f65d0e..b5f65d0e 100644
--- a/.emacs.d/lisp/key-chord.el
+++ b/.emacs.d/initlibs/key-chord.el
diff --git a/.emacs.d/lisp/let-alist.el b/.emacs.d/initlibs/let-alist.el
index dbf31e02..dbf31e02 100644
--- a/.emacs.d/lisp/let-alist.el
+++ b/.emacs.d/initlibs/let-alist.el
diff --git a/.emacs.d/lisp/smex.el b/.emacs.d/initlibs/smex.el
index 36d5b2e4..36d5b2e4 100644
--- a/.emacs.d/lisp/smex.el
+++ b/.emacs.d/initlibs/smex.el
diff --git a/.emacs.d/lisp/use-package.el b/.emacs.d/initlibs/use-package.el
index 4928ece0..4928ece0 100644
--- a/.emacs.d/lisp/use-package.el
+++ b/.emacs.d/initlibs/use-package.el
diff --git a/.emacs.d/init.el b/.emacs.d/init.el
index e7eaf061..a2306cf5 100644
--- a/.emacs.d/init.el
+++ b/.emacs.d/init.el
@@ -14,11 +14,9 @@
;; This is for my personal, possibly patched versions of libraries.
(add-to-list 'load-path (concat user-emacs-directory "site-lisp"))
;; libs in ~/.emacs.d/lisp are overridden by system packages
;; This is for fallback copies of libraries needed to init Emacs.
-;; Possible alternate name, if this is breaking Emacs conventions for
-;; dirs called 'lisp': initlibs
-(add-to-list 'load-path (concat user-emacs-directory "lisp") t)
+(add-to-list 'load-path (concat user-emacs-directory "initlibs") t)
;; be sure not to load stale byte-compiled lisp
(setq load-prefer-newer t)
@@ -45,7 +43,7 @@
;;
;; Such packages are not marked as optional, and `use-package' will
;; complain at startup if they are not available. Fallback copies
;; should be present in ~/.emacs.d/lisp.
(defun spw--optional-pkg-available-p (pkg)
(or (bound-and-true-p use-package-always-ensure)
@@ -14,11 +14,9 @@
;; This is for my personal, possibly patched versions of libraries.
(add-to-list 'load-path (concat user-emacs-directory "site-lisp"))
-;; libs in ~/.emacs.d/lisp are overridden by system packages
+;; libs in ~/.emacs.d/initlibs are overridden by system packages
;; This is for fallback copies of libraries needed to init Emacs.
@@ -45,7 +43,7 @@
;; Such packages are not marked as optional, and `use-package' will
;; complain at startup if they are not available. Fallback copies
-;; should be present in ~/.emacs.d/lisp.
+;; should be present in ~/.emacs.d/initlibs.
(defun spw--optional-pkg-available-p (pkg)
(or (bound-and-true-p use-package-always-ensure)